# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAuditGroupChild(Model):
    """BillAuditGroupChild.

    :param audit_group_id:
    :type audit_group_id: int
    :param audit_group_code:
    :type audit_group_code: str
    :param audit_group_info:
    :type audit_group_info: str
    :param description:
    :type description: str
    """

    _attribute_map = {
        'audit_group_id': {'key': 'auditGroupId', 'type': 'int'},
        'audit_group_code': {'key': 'auditGroupCode', 'type': 'str'},
        'audit_group_info': {'key': 'auditGroupInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, audit_group_id=None, audit_group_code=None, audit_group_info=None, description=None):
        super(BillAuditGroupChild, self).__init__()
        self.audit_group_id = audit_group_id
        self.audit_group_code = audit_group_code
        self.audit_group_info = audit_group_info
        self.description = description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeRequest(Model):
    """MeRequest.

    :param preference:
    :type preference: ~energycap.sdk.models.Preference
    """

    _attribute_map = {
        'preference': {'key': 'preference', 'type': 'Preference'},
    }

    def __init__(self, preference=None):
        super(MeRequest, self).__init__()
        self.preference = preference



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillUseRequest(Model):
    """Defines how use is calculated for a calculated bill distribution <span
    class='property-internal'>Only one of ReadingsChannelId, FixedAmount,
    CopyUseFromMeter, UseCalculation is required</span>.

    :param readings_channel_id: Use monthly channel data readings to calculate
     bill use
    :type readings_channel_id: int
    :param fixed_amount: Use a fixed amount of a given unit for bill use
    :type fixed_amount: ~energycap.sdk.models.FixedUseRequest
    :param copy_use_from_meter: Copy aggregated use from another meter
    :type copy_use_from_meter: ~energycap.sdk.models.CopyMeterRequest
    :param use_calculation: Adding/subtracting calculation involving meters
     and/or meter groups
    :type use_calculation: ~energycap.sdk.models.CalculationRequest
    """

    _attribute_map = {
        'readings_channel_id': {'key': 'readingsChannelId', 'type': 'int'},
        'fixed_amount': {'key': 'fixedAmount', 'type': 'FixedUseRequest'},
        'copy_use_from_meter': {'key': 'copyUseFromMeter', 'type': 'CopyMeterRequest'},
        'use_calculation': {'key': 'useCalculation', 'type': 'CalculationRequest'},
    }

    def __init__(self, readings_channel_id=None, fixed_amount=None, copy_use_from_meter=None, use_calculation=None):
        super(CalculatedBillUseRequest, self).__init__()
        self.readings_channel_id = readings_channel_id
        self.fixed_amount = fixed_amount
        self.copy_use_from_meter = copy_use_from_meter
        self.use_calculation = use_calculation



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PrimaryUseCreate(Model):
    """PrimaryUseCreate.

    :param primary_use_code: The Primary Use Code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type primary_use_code: str
    :param primary_use_info: The Primary Use Info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type primary_use_info: str
    :param primary_use_type: The Primary Use Type. Possible value include:
     "place" and "meter" <span class='property-internal'>Required</span> <span
     class='property-internal'>One of place, meter </span>
    :type primary_use_type: str
    """

    _validation = {
        'primary_use_code': {'required': True, 'max_length': 64, 'min_length': 0},
        'primary_use_info': {'required': True, 'max_length': 64, 'min_length': 0},
        'primary_use_type': {'required': True},
    }

    _attribute_map = {
        'primary_use_code': {'key': 'primaryUseCode', 'type': 'str'},
        'primary_use_info': {'key': 'primaryUseInfo', 'type': 'str'},
        'primary_use_type': {'key': 'primaryUseType', 'type': 'str'},
    }

    def __init__(self, primary_use_code, primary_use_info, primary_use_type):
        super(PrimaryUseCreate, self).__init__()
        self.primary_use_code = primary_use_code
        self.primary_use_info = primary_use_info
        self.primary_use_type = primary_use_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DistributedReportsConfiguration(Model):
    """DistributedReportsConfiguration.

    :param format:
    :type format: str
    :param use_copy:
    :type use_copy: bool
    :param filters:
    :type filters: list[~energycap.sdk.models.FilterEdit]
    :param clear_filters:
    :type clear_filters: bool
    :param save_filters:
    :type save_filters: bool
    :param only_send_if_data:
    :type only_send_if_data: bool
    :param distribution:
    :type distribution: ~energycap.sdk.models.EmailProperties
    """

    _attribute_map = {
        'format': {'key': 'format', 'type': 'str'},
        'use_copy': {'key': 'useCopy', 'type': 'bool'},
        'filters': {'key': 'filters', 'type': '[FilterEdit]'},
        'clear_filters': {'key': 'clearFilters', 'type': 'bool'},
        'save_filters': {'key': 'saveFilters', 'type': 'bool'},
        'only_send_if_data': {'key': 'onlySendIfData', 'type': 'bool'},
        'distribution': {'key': 'distribution', 'type': 'EmailProperties'},
    }

    def __init__(self, format=None, use_copy=None, filters=None, clear_filters=None, save_filters=None, only_send_if_data=None, distribution=None):
        super(DistributedReportsConfiguration, self).__init__()
        self.format = format
        self.use_copy = use_copy
        self.filters = filters
        self.clear_filters = clear_filters
        self.save_filters = save_filters
        self.only_send_if_data = only_send_if_data
        self.distribution = distribution



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Readings(Model):
    """Readings.

    :param channel_id: The Id of the Channel
    :type channel_id: int
    :param rule: 1 = odometer, 2 = trip (to calculate delta)
    :type rule: int
    :param unit: The unit of the reading
    :type unit: ~energycap.sdk.models.UnitChild
    :param readings:
    :type readings: list[~energycap.sdk.models.ReadingsObservation]
    """

    _attribute_map = {
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'rule': {'key': 'rule', 'type': 'int'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
        'readings': {'key': 'readings', 'type': '[ReadingsObservation]'},
    }

    def __init__(self, channel_id=None, rule=None, unit=None, readings=None):
        super(Readings, self).__init__()
        self.channel_id = channel_id
        self.rule = rule
        self.unit = unit
        self.readings = readings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GLSubCodeChildRequest(Model):
    """GLSubCodeChildRequest.

    :param sub_code_index: Index of this sub code (1-20) <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 1 and 20</span>
    :type sub_code_index: int
    :param value: Value for the sub code <span class='property-internal'>Must
     be between 0 and 25 characters</span>
    :type value: str
    """

    _validation = {
        'sub_code_index': {'required': True, 'maximum': 20, 'minimum': 1},
        'value': {'max_length': 25, 'min_length': 0},
    }

    _attribute_map = {
        'sub_code_index': {'key': 'subCodeIndex', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, sub_code_index, value=None):
        super(GLSubCodeChildRequest, self).__init__()
        self.sub_code_index = sub_code_index
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupRequest(Model):
    """<span class='property-internal'>Only one of AutomaticGroupFilters,
    ManualGroupMembers is required</span>.

    :param meter_group_info: The meter group info <span
     class='property-internal'>Must be between 0 and 255 characters</span>
     <span class='property-internal'>Required</span>
    :type meter_group_info: str
    :param meter_group_category_id: The meter group category <span
     class='property-internal'>Required</span>
    :type meter_group_category_id: int
    :param limit_members_by_topmost: Should this group only return members
     within the current user's topmost <span
     class='property-internal'>Required</span>
    :type limit_members_by_topmost: bool
    :param automatic_group_filters: List of filters to add members to an
     automic meter group
     Either AutomaticGroupFilters or ManualGroupMembers, but not both, must be
     passed in <span class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>NULL Valid</span>
    :type automatic_group_filters: list[~energycap.sdk.models.FilterEdit]
    :param manual_group_members: List of members to add to the group
     Either AutomaticGroupFilters or ManualGroupMembers, but not both, must be
     passed in
     Members but be within the current user's topmost
     You can create an empty group by passing in an empty array
    :type manual_group_members: list[int]
    """

    _validation = {
        'meter_group_info': {'required': True, 'max_length': 255, 'min_length': 0},
        'meter_group_category_id': {'required': True},
        'limit_members_by_topmost': {'required': True},
    }

    _attribute_map = {
        'meter_group_info': {'key': 'meterGroupInfo', 'type': 'str'},
        'meter_group_category_id': {'key': 'meterGroupCategoryId', 'type': 'int'},
        'limit_members_by_topmost': {'key': 'limitMembersByTopmost', 'type': 'bool'},
        'automatic_group_filters': {'key': 'automaticGroupFilters', 'type': '[FilterEdit]'},
        'manual_group_members': {'key': 'manualGroupMembers', 'type': '[int]'},
    }

    def __init__(self, meter_group_info, meter_group_category_id, limit_members_by_topmost, automatic_group_filters=None, manual_group_members=None):
        super(MeterGroupRequest, self).__init__()
        self.meter_group_info = meter_group_info
        self.meter_group_category_id = meter_group_category_id
        self.limit_members_by_topmost = limit_members_by_topmost
        self.automatic_group_filters = automatic_group_filters
        self.manual_group_members = manual_group_members



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestNormalizedYearlyResponseCommodityResults(Model):
    """PlaceDigestNormalizedYearlyResponseCommodityResults.

    :param year: year
    :type year: str
    :param common_use: Common Use
    :type common_use: float
    :param global_use: Global Use
    :type global_use: float
    """

    _attribute_map = {
        'year': {'key': 'year', 'type': 'str'},
        'common_use': {'key': 'commonUse', 'type': 'float'},
        'global_use': {'key': 'globalUse', 'type': 'float'},
    }

    def __init__(self, year=None, common_use=None, global_use=None):
        super(PlaceDigestNormalizedYearlyResponseCommodityResults, self).__init__()
        self.year = year
        self.common_use = common_use
        self.global_use = global_use



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificAuditCreate(Model):
    """SpecificAuditCreate.

    :param specific_audit_info: Name used to refer to this audit <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type specific_audit_info: str
    :param auditor_id: The Id of the bill audit to add to the group <span
     class='property-internal'>Required</span>
    :type auditor_id: int
    """

    _validation = {
        'specific_audit_info': {'required': True, 'max_length': 64, 'min_length': 0},
        'auditor_id': {'required': True},
    }

    _attribute_map = {
        'specific_audit_info': {'key': 'specificAuditInfo', 'type': 'str'},
        'auditor_id': {'key': 'auditorId', 'type': 'int'},
    }

    def __init__(self, specific_audit_info, auditor_id):
        super(SpecificAuditCreate, self).__init__()
        self.specific_audit_info = specific_audit_info
        self.auditor_id = auditor_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificAuditPropertyChild(Model):
    """SpecificAuditPropertyChild.

    :param property_id: The Id of the property <span
     class='property-internal'>Required</span>
    :type property_id: int
    :param value: The value for the property <span
     class='property-internal'>Required</span>
    :type value: str
    """

    _validation = {
        'property_id': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'property_id': {'key': 'propertyId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, property_id, value):
        super(SpecificAuditPropertyChild, self).__init__()
        self.property_id = property_id
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AuditCategory(Model):
    """AuditCategory.

    :param audit_category_id:
    :type audit_category_id: int
    :param audit_category_code:
    :type audit_category_code: str
    :param audit_category_info:
    :type audit_category_info: str
    """

    _attribute_map = {
        'audit_category_id': {'key': 'auditCategoryId', 'type': 'int'},
        'audit_category_code': {'key': 'auditCategoryCode', 'type': 'str'},
        'audit_category_info': {'key': 'auditCategoryInfo', 'type': 'str'},
    }

    def __init__(self, audit_category_id=None, audit_category_code=None, audit_category_info=None):
        super(AuditCategory, self).__init__()
        self.audit_category_id = audit_category_id
        self.audit_category_code = audit_category_code
        self.audit_category_info = audit_category_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupDisplaySetting(Model):
    """GroupDisplaySetting.

    :param period_type:
    :type period_type: int
    :param data_view:
    :type data_view: str
    :param commodity_id:
    :type commodity_id: int
    :param show_excluded_members:
    :type show_excluded_members: bool
    :param show_zero_averages:
    :type show_zero_averages: bool
    """

    _attribute_map = {
        'period_type': {'key': 'periodType', 'type': 'int'},
        'data_view': {'key': 'dataView', 'type': 'str'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'show_excluded_members': {'key': 'showExcludedMembers', 'type': 'bool'},
        'show_zero_averages': {'key': 'showZeroAverages', 'type': 'bool'},
    }

    def __init__(self, period_type=None, data_view=None, commodity_id=None, show_excluded_members=None, show_zero_averages=None):
        super(GroupDisplaySetting, self).__init__()
        self.period_type = period_type
        self.data_view = data_view
        self.commodity_id = commodity_id
        self.show_excluded_members = show_excluded_members
        self.show_zero_averages = show_zero_averages



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceEnergyStarPlaceTypeCreate(Model):
    """PlaceEnergyStarPlaceTypeCreate.

    :param energy_star_place_type_id: The energystar placetype identifier
    :type energy_star_place_type_id: int
    :param energy_star_place_properties: The energystar place properties
     object
    :type energy_star_place_properties:
     list[~energycap.sdk.models.EnergyStarPlacePropertyCreate]
    """

    _attribute_map = {
        'energy_star_place_type_id': {'key': 'energyStarPlaceTypeId', 'type': 'int'},
        'energy_star_place_properties': {'key': 'energyStarPlaceProperties', 'type': '[EnergyStarPlacePropertyCreate]'},
    }

    def __init__(self, energy_star_place_type_id=None, energy_star_place_properties=None):
        super(PlaceEnergyStarPlaceTypeCreate, self).__init__()
        self.energy_star_place_type_id = energy_star_place_type_id
        self.energy_star_place_properties = energy_star_place_properties



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountPeriodResponse(Model):
    """AccountPeriodResponse.

    :param account_period_id: The account period identifier
    :type account_period_id: int
    :param period_number: The period number
    :type period_number: int
    :param name: The name of the period
    :type name: str
    """

    _attribute_map = {
        'account_period_id': {'key': 'accountPeriodId', 'type': 'int'},
        'period_number': {'key': 'periodNumber', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(self, account_period_id=None, period_number=None, name=None):
        super(AccountPeriodResponse, self).__init__()
        self.account_period_id = account_period_id
        self.period_number = period_number
        self.name = name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillDemandResponse(Model):
    """CalculatedBillDemandResponse.

    :param readings_from_channel: Use channel data readings to calculate bill
     demand
    :type readings_from_channel:
     ~energycap.sdk.models.ChannelChildWithObservationType
    :param fixed_demand: Use a fixed amount for calculate bill demand
    :type fixed_demand: ~energycap.sdk.models.FixedAmountResponse
    """

    _attribute_map = {
        'readings_from_channel': {'key': 'readingsFromChannel', 'type': 'ChannelChildWithObservationType'},
        'fixed_demand': {'key': 'fixedDemand', 'type': 'FixedAmountResponse'},
    }

    def __init__(self, readings_from_channel=None, fixed_demand=None):
        super(CalculatedBillDemandResponse, self).__init__()
        self.readings_from_channel = readings_from_channel
        self.fixed_demand = fixed_demand



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyProjectResponse(Model):
    """EnergyProjectResponse.

    :param energy_project_id: The energy project identifier
    :type energy_project_id: int
    :param energy_project_code: The energy project code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span> <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type energy_project_code: str
    :param energy_project_info: The energy project info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span> <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type energy_project_info: str
    :param installation_begin_date: The energy project installation begin date
    :type installation_begin_date: datetime
    :param installation_end_date: The energy project installation end date
    :type installation_end_date: datetime
    :param installation_cost: The energy project installation cost
    :type installation_cost: float
    :param utility_rebate: The rebate amount of energy project
    :type utility_rebate: float
    :param funding_source: The funding source of the project
    :type funding_source: str
    :param project_manager: The project manager of the energy project
    :type project_manager: str
    :param note: The miscellenous note about the project
    :type note: str
    :param energy_savings: The energy savings
    :type energy_savings: ~energycap.sdk.models.EnergySavingsChild
    :param cost_savings: The cost savings
    :type cost_savings: ~energycap.sdk.models.CostSavingsChild
    :param place: The place of the energy project
    :type place: ~energycap.sdk.models.EnergyProjectPlaceChild
    :param energy_project_type: The project type of the energy project
    :type energy_project_type: ~energycap.sdk.models.EnergyProjectType
    """

    _validation = {
        'energy_project_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'energy_project_info': {'required': True, 'max_length': 50, 'min_length': 0},
    }

    _attribute_map = {
        'energy_project_id': {'key': 'energyProjectId', 'type': 'int'},
        'energy_project_code': {'key': 'energyProjectCode', 'type': 'str'},
        'energy_project_info': {'key': 'energyProjectInfo', 'type': 'str'},
        'installation_begin_date': {'key': 'installationBeginDate', 'type': 'iso-8601'},
        'installation_end_date': {'key': 'installationEndDate', 'type': 'iso-8601'},
        'installation_cost': {'key': 'installationCost', 'type': 'float'},
        'utility_rebate': {'key': 'utilityRebate', 'type': 'float'},
        'funding_source': {'key': 'fundingSource', 'type': 'str'},
        'project_manager': {'key': 'projectManager', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
        'energy_savings': {'key': 'energySavings', 'type': 'EnergySavingsChild'},
        'cost_savings': {'key': 'costSavings', 'type': 'CostSavingsChild'},
        'place': {'key': 'place', 'type': 'EnergyProjectPlaceChild'},
        'energy_project_type': {'key': 'energyProjectType', 'type': 'EnergyProjectType'},
    }

    def __init__(self, energy_project_code, energy_project_info, energy_project_id=None, installation_begin_date=None, installation_end_date=None, installation_cost=None, utility_rebate=None, funding_source=None, project_manager=None, note=None, energy_savings=None, cost_savings=None, place=None, energy_project_type=None):
        super(EnergyProjectResponse, self).__init__()
        self.energy_project_id = energy_project_id
        self.energy_project_code = energy_project_code
        self.energy_project_info = energy_project_info
        self.installation_begin_date = installation_begin_date
        self.installation_end_date = installation_end_date
        self.installation_cost = installation_cost
        self.utility_rebate = utility_rebate
        self.funding_source = funding_source
        self.project_manager = project_manager
        self.note = note
        self.energy_savings = energy_savings
        self.cost_savings = cost_savings
        self.place = place
        self.energy_project_type = energy_project_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillActionHeaderUpdate(Model):
    """BillActionHeaderUpdate.

    :param bill_ids: Bill IDs whose headers are going to be updated <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required</span>
    :type bill_ids: list[int]
    :param bill_header: Bill header values to update <span
     class='property-internal'>Required</span>
    :type bill_header: ~energycap.sdk.models.BillHeaderUpdate
    """

    _validation = {
        'bill_ids': {'required': True},
        'bill_header': {'required': True},
    }

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'bill_header': {'key': 'billHeader', 'type': 'BillHeaderUpdate'},
    }

    def __init__(self, bill_ids, bill_header):
        super(BillActionHeaderUpdate, self).__init__()
        self.bill_ids = bill_ids
        self.bill_header = bill_header



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportEdit(Model):
    """ReportEdit.

    :param report_code: New specific report code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type report_code: str
    :param report_info: New specific report name <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type report_info: str
    :param report_description: New specific report description <span
     class='property-internal'>Required</span>
    :type report_description: str
    """

    _validation = {
        'report_code': {'required': True, 'max_length': 16, 'min_length': 0},
        'report_info': {'required': True, 'max_length': 255, 'min_length': 0},
        'report_description': {'required': True},
    }

    _attribute_map = {
        'report_code': {'key': 'reportCode', 'type': 'str'},
        'report_info': {'key': 'reportInfo', 'type': 'str'},
        'report_description': {'key': 'reportDescription', 'type': 'str'},
    }

    def __init__(self, report_code, report_info, report_description):
        super(ReportEdit, self).__init__()
        self.report_code = report_code
        self.report_info = report_info
        self.report_description = report_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetResponse(Model):
    """WidgetResponse.

    :param widget_id: Widget identifier
    :type widget_id: int
    :param widget_info: Widget info
    :type widget_info: str
    :param description: Widget description
    :type description: str
    :param tags: Widget tags
    :type tags: list[str]
    :param filters: Widget filters
    :type filters: list[~energycap.sdk.models.FilterResponse]
    """

    _attribute_map = {
        'widget_id': {'key': 'widgetId', 'type': 'int'},
        'widget_info': {'key': 'widgetInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '[str]'},
        'filters': {'key': 'filters', 'type': '[FilterResponse]'},
    }

    def __init__(self, widget_id=None, widget_info=None, description=None, tags=None, filters=None):
        super(WidgetResponse, self).__init__()
        self.widget_id = widget_id
        self.widget_info = widget_info
        self.description = description
        self.tags = tags
        self.filters = filters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillUseResponse(Model):
    """Definition of how a calculated bill will get its use.

    :param readings_from_channel: Use monthly channel data readings to
     calculate bill use
    :type readings_from_channel:
     ~energycap.sdk.models.ChannelChildWithObservationType
    :param fixed_amount: Use a fixed amount for bill use
    :type fixed_amount: ~energycap.sdk.models.FixedAmountResponse
    :param copy_use_from_meter: Copy aggregated use from another meter
    :type copy_use_from_meter: ~energycap.sdk.models.CopyFromMeterResponse
    :param use_calculation: Add and subtract use from meters and meter groups
    :type use_calculation: ~energycap.sdk.models.CalculationResponse
    """

    _attribute_map = {
        'readings_from_channel': {'key': 'readingsFromChannel', 'type': 'ChannelChildWithObservationType'},
        'fixed_amount': {'key': 'fixedAmount', 'type': 'FixedAmountResponse'},
        'copy_use_from_meter': {'key': 'copyUseFromMeter', 'type': 'CopyFromMeterResponse'},
        'use_calculation': {'key': 'useCalculation', 'type': 'CalculationResponse'},
    }

    def __init__(self, readings_from_channel=None, fixed_amount=None, copy_use_from_meter=None, use_calculation=None):
        super(CalculatedBillUseResponse, self).__init__()
        self.readings_from_channel = readings_from_channel
        self.fixed_amount = fixed_amount
        self.copy_use_from_meter = copy_use_from_meter
        self.use_calculation = use_calculation



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BulkBaselineProcessorRequest(Model):
    """BulkBaselineProcessorRequest.

    :param ignore_weather_adjustments: Determines if weather adjustments are
     applied to the reprocessed baseline or not
     Defaults to "false"
    :type ignore_weather_adjustments: bool
    :param filters: Filter criteria which determine the meters whose cost
     avoidance baselines will be reprocessed <span
     class='property-internal'>Cannot be Empty</span>
    :type filters: list[~energycap.sdk.models.FilterEdit]
    """

    _attribute_map = {
        'ignore_weather_adjustments': {'key': 'ignoreWeatherAdjustments', 'type': 'bool'},
        'filters': {'key': 'filters', 'type': '[FilterEdit]'},
    }

    def __init__(self, ignore_weather_adjustments=None, filters=None):
        super(BulkBaselineProcessorRequest, self).__init__()
        self.ignore_weather_adjustments = ignore_weather_adjustments
        self.filters = filters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListColumnEdit(Model):
    """ListColumnEdit.

    :param field_id:  <span class='property-internal'>Required</span>
    :type field_id: int
    :param width:  <span class='property-internal'>Required</span>
    :type width: int
    :param display_order:  <span class='property-internal'>Required</span>
    :type display_order: int
    :param sort_order:  <span class='property-internal'>Required</span>
    :type sort_order: int
    :param sort_direction:  <span class='property-internal'>Required</span>
     <span class='property-internal'>One of asc, desc </span>
    :type sort_direction: str
    :param visible:  <span class='property-internal'>Required</span>
    :type visible: bool
    """

    _validation = {
        'field_id': {'required': True},
        'width': {'required': True},
        'display_order': {'required': True},
        'sort_order': {'required': True},
        'sort_direction': {'required': True},
        'visible': {'required': True},
    }

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'int'},
        'width': {'key': 'width', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'sort_order': {'key': 'sortOrder', 'type': 'int'},
        'sort_direction': {'key': 'sortDirection', 'type': 'str'},
        'visible': {'key': 'visible', 'type': 'bool'},
    }

    def __init__(self, field_id, width, display_order, sort_order, sort_direction, visible):
        super(ListColumnEdit, self).__init__()
        self.field_id = field_id
        self.width = width
        self.display_order = display_order
        self.sort_order = sort_order
        self.sort_direction = sort_direction
        self.visible = visible



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardResponse(Model):
    """DashboardResponse.

    :param dashboard_id: The dashboard identifier
    :type dashboard_id: int
    :param dashboard_info: The dashboard info
    :type dashboard_info: str
    :param description: The dashboard description
    :type description: str
    :param type: The dashboard type
    :type type: str
    :param created_by: The user who created the dashboard
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The date and time the dashboard was created
    :type created_date: datetime
    :param modified_date: The date and time of the most recent modification
    :type modified_date: datetime
    :param shared: Flag to indicate if the dashboard is shared
    :type shared: bool
    :param visible: Flag to indicate if the dashboard is visible
    :type visible: bool
    :param last_viewed: The date and time of the last time this dashboard was
     viewed
    :type last_viewed: datetime
    :param key: If the dashboard is public, this value holds the public key
     that allows the dashboard to be embedded
    :type key: str
    :param public: Flag to indicate if the dashboard is public
    :type public: bool
    """

    _attribute_map = {
        'dashboard_id': {'key': 'dashboardId', 'type': 'int'},
        'dashboard_info': {'key': 'dashboardInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'shared': {'key': 'shared', 'type': 'bool'},
        'visible': {'key': 'visible', 'type': 'bool'},
        'last_viewed': {'key': 'lastViewed', 'type': 'iso-8601'},
        'key': {'key': 'key', 'type': 'str'},
        'public': {'key': 'public', 'type': 'bool'},
    }

    def __init__(self, dashboard_id=None, dashboard_info=None, description=None, type=None, created_by=None, created_date=None, modified_date=None, shared=None, visible=None, last_viewed=None, key=None, public=None):
        super(DashboardResponse, self).__init__()
        self.dashboard_id = dashboard_id
        self.dashboard_info = dashboard_info
        self.description = description
        self.type = type
        self.created_by = created_by
        self.created_date = created_date
        self.modified_date = modified_date
        self.shared = shared
        self.visible = visible
        self.last_viewed = last_viewed
        self.key = key
        self.public = public



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillViewAccountChild(Model):
    """BillViewAccountChild.

    :param account_id:
    :type account_id: int
    :param account_code:
    :type account_code: str
    :param account_info:
    :type account_info: str
    :param account_type:
    :type account_type: ~energycap.sdk.models.AccountTypeChild
    :param address:
    :type address: ~energycap.sdk.models.BillViewAddressChild
    :param vendor:
    :type vendor: ~energycap.sdk.models.BillViewVendorChild
    :param general_ledger:
    :type general_ledger: ~energycap.sdk.models.GeneralLedgerChild
    """

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'account_type': {'key': 'accountType', 'type': 'AccountTypeChild'},
        'address': {'key': 'address', 'type': 'BillViewAddressChild'},
        'vendor': {'key': 'vendor', 'type': 'BillViewVendorChild'},
        'general_ledger': {'key': 'generalLedger', 'type': 'GeneralLedgerChild'},
    }

    def __init__(self, account_id=None, account_code=None, account_info=None, account_type=None, address=None, vendor=None, general_ledger=None):
        super(BillViewAccountChild, self).__init__()
        self.account_id = account_id
        self.account_code = account_code
        self.account_info = account_info
        self.account_type = account_type
        self.address = address
        self.vendor = vendor
        self.general_ledger = general_ledger



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class StringSegment(Model):
    """StringSegment.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar buffer:
    :vartype buffer: str
    :ivar offset:
    :vartype offset: int
    :ivar length:
    :vartype length: int
    :ivar value:
    :vartype value: str
    :ivar has_value:
    :vartype has_value: bool
    """

    _validation = {
        'buffer': {'readonly': True},
        'offset': {'readonly': True},
        'length': {'readonly': True},
        'value': {'readonly': True},
        'has_value': {'readonly': True},
    }

    _attribute_map = {
        'buffer': {'key': 'buffer', 'type': 'str'},
        'offset': {'key': 'offset', 'type': 'int'},
        'length': {'key': 'length', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
        'has_value': {'key': 'hasValue', 'type': 'bool'},
    }

    def __init__(self):
        super(StringSegment, self).__init__()
        self.buffer = None
        self.offset = None
        self.length = None
        self.value = None
        self.has_value = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchResponse(Model):
    """SearchResponse.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param cost_centers: The collection of cost centers
    :type cost_centers: list[~energycap.sdk.models.SearchCostCenterChild]
    :param accounts: The collection of accounts
    :type accounts: list[~energycap.sdk.models.SearchAccountChild]
    :param places: The collection of places
    :type places: list[~energycap.sdk.models.SearchPlaceChild]
    :param meters: The collection of meters
    :type meters: list[~energycap.sdk.models.SearchMeterChild]
    :ivar place_groups: The collection of place groups
    :vartype place_groups: list[~energycap.sdk.models.SearchPlaceGroup]
    """

    _validation = {
        'place_groups': {'readonly': True},
    }

    _attribute_map = {
        'cost_centers': {'key': 'costCenters', 'type': '[SearchCostCenterChild]'},
        'accounts': {'key': 'accounts', 'type': '[SearchAccountChild]'},
        'places': {'key': 'places', 'type': '[SearchPlaceChild]'},
        'meters': {'key': 'meters', 'type': '[SearchMeterChild]'},
        'place_groups': {'key': 'placeGroups', 'type': '[SearchPlaceGroup]'},
    }

    def __init__(self, cost_centers=None, accounts=None, places=None, meters=None):
        super(SearchResponse, self).__init__()
        self.cost_centers = cost_centers
        self.accounts = accounts
        self.places = places
        self.meters = meters
        self.place_groups = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateResponse(Model):
    """BillHeaderUpdateResponse.

    :param bill_update_statuses:
    :type bill_update_statuses:
     list[~energycap.sdk.models.BillHeaderUpdateResponseChild]
    :param selected:
    :type selected: int
    :param updated:
    :type updated: int
    """

    _attribute_map = {
        'bill_update_statuses': {'key': 'billUpdateStatuses', 'type': '[BillHeaderUpdateResponseChild]'},
        'selected': {'key': 'selected', 'type': 'int'},
        'updated': {'key': 'updated', 'type': 'int'},
    }

    def __init__(self, bill_update_statuses=None, selected=None, updated=None):
        super(BillHeaderUpdateResponse, self).__init__()
        self.bill_update_statuses = bill_update_statuses
        self.selected = selected
        self.updated = updated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergystarPlace(Model):
    """EnergystarPlace.

    :param place: The building
    :type place: ~energycap.sdk.models.PlaceChild
    :param address: The address for the building
    :type address: ~energycap.sdk.models.AddressChild
    :param energystar_rating: The current ENERGY STAR rating
    :type energystar_rating: int
    :param energystar_rating_date: The date that the building received the
     current ENERGY STAR rating
    :type energystar_rating_date: datetime
    :param is_energystar_turned_on: Whether or not ENERGY STAR submissions are
     enabled for the building
    :type is_energystar_turned_on: bool
    :param current_area: Current floor area value for the building
    :type current_area: int
    :param current_area_unit: Current floor area unit for the building
    :type current_area_unit: str
    """

    _attribute_map = {
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'energystar_rating': {'key': 'energystarRating', 'type': 'int'},
        'energystar_rating_date': {'key': 'energystarRatingDate', 'type': 'iso-8601'},
        'is_energystar_turned_on': {'key': 'isEnergystarTurnedOn', 'type': 'bool'},
        'current_area': {'key': 'currentArea', 'type': 'int'},
        'current_area_unit': {'key': 'currentAreaUnit', 'type': 'str'},
    }

    def __init__(self, place=None, address=None, energystar_rating=None, energystar_rating_date=None, is_energystar_turned_on=None, current_area=None, current_area_unit=None):
        super(EnergystarPlace, self).__init__()
        self.place = place
        self.address = address
        self.energystar_rating = energystar_rating
        self.energystar_rating_date = energystar_rating_date
        self.is_energystar_turned_on = is_energystar_turned_on
        self.current_area = current_area
        self.current_area_unit = current_area_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificAuditResponse(Model):
    """SpecificAuditResponse.

    :param audit_category:
    :type audit_category: ~energycap.sdk.models.AuditCategory
    :param alert_severity:
    :type alert_severity: ~energycap.sdk.models.AlertSeverityResponse
    :param skip_zero_comparison:
    :type skip_zero_comparison: bool
    :param properties:
    :type properties: list[~energycap.sdk.models.AuditProperty]
    :param specific_audit_id:
    :type specific_audit_id: int
    :param specific_audit_info:
    :type specific_audit_info: str
    :param auditor_id:
    :type auditor_id: int
    :param auditor_code:
    :type auditor_code: str
    :param description:
    :type description: str
    """

    _attribute_map = {
        'audit_category': {'key': 'auditCategory', 'type': 'AuditCategory'},
        'alert_severity': {'key': 'alertSeverity', 'type': 'AlertSeverityResponse'},
        'skip_zero_comparison': {'key': 'skipZeroComparison', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '[AuditProperty]'},
        'specific_audit_id': {'key': 'specificAuditId', 'type': 'int'},
        'specific_audit_info': {'key': 'specificAuditInfo', 'type': 'str'},
        'auditor_id': {'key': 'auditorId', 'type': 'int'},
        'auditor_code': {'key': 'auditorCode', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, audit_category=None, alert_severity=None, skip_zero_comparison=None, properties=None, specific_audit_id=None, specific_audit_info=None, auditor_id=None, auditor_code=None, description=None):
        super(SpecificAuditResponse, self).__init__()
        self.audit_category = audit_category
        self.alert_severity = alert_severity
        self.skip_zero_comparison = skip_zero_comparison
        self.properties = properties
        self.specific_audit_id = specific_audit_id
        self.specific_audit_info = specific_audit_info
        self.auditor_id = auditor_id
        self.auditor_code = auditor_code
        self.description = description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OtherSavingsResponse(Model):
    """OtherSavingsResponse.

    :param other_savings_id: Other savings identifier
    :type other_savings_id: int
    :param frequency: Other savings frequency
     Possible values are: one-time, continuous, and recurring
    :type frequency: str
    :param other_savings_category: Other savings category
    :type other_savings_category: ~energycap.sdk.models.OtherSavingsCategory
    :param description: Description
    :type description: str
    :param start_period: Begin period for the other savings
    :type start_period: int
    :param end_period: End period for the other savings
    :type end_period: int
    :param annnual_cycle_start_month: Month the other savings should begin
     This is only set when the other savings type is recurring
    :type annnual_cycle_start_month: int
    :param annual_cycle_end_month: Month the other savings should end
     This is only set when the other savings type is recurring
    :type annual_cycle_end_month: int
    :param value: Amount saved
    :type value: float
    :param created_by: User who created the other savings
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: Create date
    :type created_date: datetime
    :param modified_by: Last user to modify the other savings
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: Last modified date
    :type modified_date: datetime
    :param cost_unit: Cost unit for the other savings value
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'other_savings_id': {'key': 'otherSavingsId', 'type': 'int'},
        'frequency': {'key': 'frequency', 'type': 'str'},
        'other_savings_category': {'key': 'otherSavingsCategory', 'type': 'OtherSavingsCategory'},
        'description': {'key': 'description', 'type': 'str'},
        'start_period': {'key': 'startPeriod', 'type': 'int'},
        'end_period': {'key': 'endPeriod', 'type': 'int'},
        'annnual_cycle_start_month': {'key': 'annnualCycleStartMonth', 'type': 'int'},
        'annual_cycle_end_month': {'key': 'annualCycleEndMonth', 'type': 'int'},
        'value': {'key': 'value', 'type': 'float'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, other_savings_id=None, frequency=None, other_savings_category=None, description=None, start_period=None, end_period=None, annnual_cycle_start_month=None, annual_cycle_end_month=None, value=None, created_by=None, created_date=None, modified_by=None, modified_date=None, cost_unit=None):
        super(OtherSavingsResponse, self).__init__()
        self.other_savings_id = other_savings_id
        self.frequency = frequency
        self.other_savings_category = other_savings_category
        self.description = description
        self.start_period = start_period
        self.end_period = end_period
        self.annnual_cycle_start_month = annnual_cycle_start_month
        self.annual_cycle_end_month = annual_cycle_end_month
        self.value = value
        self.created_by = created_by
        self.created_date = created_date
        self.modified_by = modified_by
        self.modified_date = modified_date
        self.cost_unit = cost_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingsObservation(Model):
    """ReadingsObservation.

    :param observation_id: The unique ID for the reading
    :type observation_id: long
    :param time: The date and time of the reading
    :type time: datetime
    :param value: The raw or computed value of the reading
    :type value: float
    :param raw_value: The raw value of the reading (before multiplier or delta
     are applied)
    :type raw_value: float
    :param estimated: Indicates if the reading is estimated
    :type estimated: bool
    :param note: A note pertaining to the reading
    :type note: str
    """

    _attribute_map = {
        'observation_id': {'key': 'observationId', 'type': 'long'},
        'time': {'key': 'time', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'raw_value': {'key': 'rawValue', 'type': 'float'},
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, observation_id=None, time=None, value=None, raw_value=None, estimated=None, note=None):
        super(ReadingsObservation, self).__init__()
        self.observation_id = observation_id
        self.time = time
        self.value = value
        self.raw_value = raw_value
        self.estimated = estimated
        self.note = note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingImportRequest(Model):
    """ReadingImportRequest.

    :param profile_code: A reading import data profile code.
    :type profile_code: str
    :param inline_profile: A reading import data profile definition.
    :type inline_profile: ~energycap.sdk.models.ReadingImportProfile
    :param data: The base64 encoded file. <span
     class='property-internal'>Required</span>
    :type data: str
    :param auto_create_channels: Create new channels if they don't exist?
    :type auto_create_channels: bool
    :param import_note: Optional note/comment.
    :type import_note: str
    """

    _validation = {
        'data': {'required': True},
    }

    _attribute_map = {
        'profile_code': {'key': 'profileCode', 'type': 'str'},
        'inline_profile': {'key': 'inlineProfile', 'type': 'ReadingImportProfile'},
        'data': {'key': 'data', 'type': 'str'},
        'auto_create_channels': {'key': 'autoCreateChannels', 'type': 'bool'},
        'import_note': {'key': 'importNote', 'type': 'str'},
    }

    def __init__(self, data, profile_code=None, inline_profile=None, auto_create_channels=None, import_note=None):
        super(ReadingImportRequest, self).__init__()
        self.profile_code = profile_code
        self.inline_profile = inline_profile
        self.data = data
        self.auto_create_channels = auto_create_channels
        self.import_note = import_note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillTemplateUnitMismatchResponse(Model):
    """BillTemplateUnitMismatchResponse.

    :param account_meter_id:
    :type account_meter_id: int
    :param meter:
    :type meter: ~energycap.sdk.models.UnitSystemMeterChild
    :param account:
    :type account: ~energycap.sdk.models.AccountChild
    :param template:
    :type template: ~energycap.sdk.models.UnitSystemTemplateChild
    :param meter_commodity_mismatches:
    :type meter_commodity_mismatches:
     list[~energycap.sdk.models.CommodityMismatchChild]
    :param bill_commodity_mismatches:
    :type bill_commodity_mismatches:
     list[~energycap.sdk.models.CommodityMismatchChild]
    :param use_mismatches:
    :type use_mismatches: list[~energycap.sdk.models.UnitMismatchChild]
    :param actual_demand_mismatches:
    :type actual_demand_mismatches:
     list[~energycap.sdk.models.UnitMismatchChild]
    :param billed_demand_mismatches:
    :type billed_demand_mismatches:
     list[~energycap.sdk.models.UnitMismatchChild]
    """

    _attribute_map = {
        'account_meter_id': {'key': 'accountMeterId', 'type': 'int'},
        'meter': {'key': 'meter', 'type': 'UnitSystemMeterChild'},
        'account': {'key': 'account', 'type': 'AccountChild'},
        'template': {'key': 'template', 'type': 'UnitSystemTemplateChild'},
        'meter_commodity_mismatches': {'key': 'meterCommodityMismatches', 'type': '[CommodityMismatchChild]'},
        'bill_commodity_mismatches': {'key': 'billCommodityMismatches', 'type': '[CommodityMismatchChild]'},
        'use_mismatches': {'key': 'useMismatches', 'type': '[UnitMismatchChild]'},
        'actual_demand_mismatches': {'key': 'actualDemandMismatches', 'type': '[UnitMismatchChild]'},
        'billed_demand_mismatches': {'key': 'billedDemandMismatches', 'type': '[UnitMismatchChild]'},
    }

    def __init__(self, account_meter_id=None, meter=None, account=None, template=None, meter_commodity_mismatches=None, bill_commodity_mismatches=None, use_mismatches=None, actual_demand_mismatches=None, billed_demand_mismatches=None):
        super(BillTemplateUnitMismatchResponse, self).__init__()
        self.account_meter_id = account_meter_id
        self.meter = meter
        self.account = account
        self.template = template
        self.meter_commodity_mismatches = meter_commodity_mismatches
        self.bill_commodity_mismatches = bill_commodity_mismatches
        self.use_mismatches = use_mismatches
        self.actual_demand_mismatches = actual_demand_mismatches
        self.billed_demand_mismatches = billed_demand_mismatches



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Frequency(Model):
    """Frequency.

    :param frequency: Frequency of special adjustment (Continuous or
     Recurring)
    :type frequency: str
    :param start_date: Start date
    :type start_date: datetime
    :param end_date: End date
    :type end_date: datetime
    :param annual_cycle_start_mmdd: Frequency start period
    :type annual_cycle_start_mmdd: int
    :param annual_cycle_end_mmdd: Frequency end period
    :type annual_cycle_end_mmdd: int
    :param annual_cycle_start_info: Frency cycle beginning of recurrence
     (format is MMM DD)
    :type annual_cycle_start_info: str
    :param annual_cycle_end_info: Frequency cycle end of recurrence (format is
     MMM DD)
    :type annual_cycle_end_info: str
    """

    _attribute_map = {
        'frequency': {'key': 'frequency', 'type': 'str'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'annual_cycle_start_mmdd': {'key': 'annualCycleStartMMDD', 'type': 'int'},
        'annual_cycle_end_mmdd': {'key': 'annualCycleEndMMDD', 'type': 'int'},
        'annual_cycle_start_info': {'key': 'annualCycleStartInfo', 'type': 'str'},
        'annual_cycle_end_info': {'key': 'annualCycleEndInfo', 'type': 'str'},
    }

    def __init__(self, frequency=None, start_date=None, end_date=None, annual_cycle_start_mmdd=None, annual_cycle_end_mmdd=None, annual_cycle_start_info=None, annual_cycle_end_info=None):
        super(Frequency, self).__init__()
        self.frequency = frequency
        self.start_date = start_date
        self.end_date = end_date
        self.annual_cycle_start_mmdd = annual_cycle_start_mmdd
        self.annual_cycle_end_mmdd = annual_cycle_end_mmdd
        self.annual_cycle_start_info = annual_cycle_start_info
        self.annual_cycle_end_info = annual_cycle_end_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemUserRoleChild(Model):
    """SystemUserRoleChild.

    :param user_role_id: The user role identifier
    :type user_role_id: int
    :param user_role_info: The user role name
    :type user_role_info: str
    """

    _attribute_map = {
        'user_role_id': {'key': 'userRoleId', 'type': 'int'},
        'user_role_info': {'key': 'userRoleInfo', 'type': 'str'},
    }

    def __init__(self, user_role_id=None, user_role_info=None):
        super(SystemUserRoleChild, self).__init__()
        self.user_role_id = user_role_id
        self.user_role_info = user_role_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CostSavingsChild(Model):
    """CostSavingsChild.

    :param cost_savings: The cost savings amount
    :type cost_savings: float
    :param cost_savings_unit: The cost savings unit
    :type cost_savings_unit: ~energycap.sdk.models.CostSavingsUnit
    """

    _attribute_map = {
        'cost_savings': {'key': 'costSavings', 'type': 'float'},
        'cost_savings_unit': {'key': 'costSavingsUnit', 'type': 'CostSavingsUnit'},
    }

    def __init__(self, cost_savings=None, cost_savings_unit=None):
        super(CostSavingsChild, self).__init__()
        self.cost_savings = cost_savings
        self.cost_savings_unit = cost_savings_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# coding: utf-8

from setuptools import setup, find_packages

NAME = "EnergyCapSdk"
VERSION = "7.3.1952"

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["msrest>=0.2.0"]

setup(
    name=NAME,
    version=VERSION,
    description="EnergyCapApi",
    author_email="",
    url="",
    keywords=["Swagger", "EnergyCapApi"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    EnergyCAP API
    """
)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceCost(Model):
    """PlaceCost.

    :param place: Place
    :type place: ~energycap.sdk.models.PlaceChild
    :param total_cost: Total cost
    :type total_cost: float
    :param current_area: Current Area
    :type current_area: int
    :param current_area_unit: Current Area Units
    :type current_area_unit: str
    :param area_unit: Area Units
    :type area_unit: str
    :param cost_per_area: Cost per area
    :type cost_per_area: float
    :param cost_unit: The cost unit of measure
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'current_area': {'key': 'currentArea', 'type': 'int'},
        'current_area_unit': {'key': 'currentAreaUnit', 'type': 'str'},
        'area_unit': {'key': 'areaUnit', 'type': 'str'},
        'cost_per_area': {'key': 'costPerArea', 'type': 'float'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, place=None, total_cost=None, current_area=None, current_area_unit=None, area_unit=None, cost_per_area=None, cost_unit=None):
        super(PlaceCost, self).__init__()
        self.place = place
        self.total_cost = total_cost
        self.current_area = current_area
        self.current_area_unit = current_area_unit
        self.area_unit = area_unit
        self.cost_per_area = cost_per_area
        self.cost_unit = cost_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CustomerResponse(Model):
    """CustomerResponse.

    :param customer_id: The customer identifier
    :type customer_id: int
    :param customer_code: The customer code
    :type customer_code: str
    :param customer_info: The customer info
    :type customer_info: str
    :param address: The address of the customer
    :type address: ~energycap.sdk.models.AddressChild
    """

    _attribute_map = {
        'customer_id': {'key': 'customerId', 'type': 'int'},
        'customer_code': {'key': 'customerCode', 'type': 'str'},
        'customer_info': {'key': 'customerInfo', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChild'},
    }

    def __init__(self, customer_id=None, customer_code=None, customer_info=None, address=None):
        super(CustomerResponse, self).__init__()
        self.customer_id = customer_id
        self.customer_code = customer_code
        self.customer_info = customer_info
        self.address = address



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserResponse(Model):
    """UserResponse.

    :param user_id: User Identifier
    :type user_id: int
    :param user_code: User Code
    :type user_code: str
    :param full_name: Full name of the user
    :type full_name: str
    :param user_role: User role assigned to this user
    :type user_role: ~energycap.sdk.models.SystemUserRoleChild
    :param cost_center: Topmost cost center allowed for the user
    :type cost_center: ~energycap.sdk.models.CostCenterChild
    :param place: Topmost place allowed for user
    :type place: ~energycap.sdk.models.PlaceChild
    :param active_directory: Is this a active directory user?
    :type active_directory: bool
    :param active: User is active or inactive
    :type active: bool
    :param email: Email ID of the user
    :type email: str
    :param password_expiration_interval: Days until password expires
    :type password_expiration_interval: int
    :param strong_password: Does user need a strong password - at least 8
     character long, one upper case, one number, one special char
    :type strong_password: bool
    :param force_password_change: Should the user be forced to change password
     on next login
    :type force_password_change: bool
    :param max_approval_amount: Max Total cost of bill this user is allowed to
     approve
    :type max_approval_amount: int
    :param last_login: last time the user logged in
    :type last_login: datetime
    :param report_group: The report group this user belongs to
    :type report_group: ~energycap.sdk.models.ReportGroupChildResponse
    """

    _attribute_map = {
        'user_id': {'key': 'userId', 'type': 'int'},
        'user_code': {'key': 'userCode', 'type': 'str'},
        'full_name': {'key': 'fullName', 'type': 'str'},
        'user_role': {'key': 'userRole', 'type': 'SystemUserRoleChild'},
        'cost_center': {'key': 'costCenter', 'type': 'CostCenterChild'},
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'active_directory': {'key': 'activeDirectory', 'type': 'bool'},
        'active': {'key': 'active', 'type': 'bool'},
        'email': {'key': 'email', 'type': 'str'},
        'password_expiration_interval': {'key': 'passwordExpirationInterval', 'type': 'int'},
        'strong_password': {'key': 'strongPassword', 'type': 'bool'},
        'force_password_change': {'key': 'forcePasswordChange', 'type': 'bool'},
        'max_approval_amount': {'key': 'maxApprovalAmount', 'type': 'int'},
        'last_login': {'key': 'lastLogin', 'type': 'iso-8601'},
        'report_group': {'key': 'reportGroup', 'type': 'ReportGroupChildResponse'},
    }

    def __init__(self, user_id=None, user_code=None, full_name=None, user_role=None, cost_center=None, place=None, active_directory=None, active=None, email=None, password_expiration_interval=None, strong_password=None, force_password_change=None, max_approval_amount=None, last_login=None, report_group=None):
        super(UserResponse, self).__init__()
        self.user_id = user_id
        self.user_code = user_code
        self.full_name = full_name
        self.user_role = user_role
        self.cost_center = cost_center
        self.place = place
        self.active_directory = active_directory
        self.active = active
        self.email = email
        self.password_expiration_interval = password_expiration_interval
        self.strong_password = strong_password
        self.force_password_change = force_password_change
        self.max_approval_amount = max_approval_amount
        self.last_login = last_login
        self.report_group = report_group



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillDemandRequest(Model):
    """<span class='property-internal'>Only one of ReadingsChannelId, FixedDemand
    is required</span>.

    :param readings_channel_id: Use channel data readings to calculate bill
     demand
    :type readings_channel_id: int
    :param fixed_demand: Use a fixed amount of a given unit for bill demand
    :type fixed_demand: ~energycap.sdk.models.FixedDemandRequest
    """

    _attribute_map = {
        'readings_channel_id': {'key': 'readingsChannelId', 'type': 'int'},
        'fixed_demand': {'key': 'fixedDemand', 'type': 'FixedDemandRequest'},
    }

    def __init__(self, readings_channel_id=None, fixed_demand=None):
        super(CalculatedBillDemandRequest, self).__init__()
        self.readings_channel_id = readings_channel_id
        self.fixed_demand = fixed_demand



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackProcessorSettingsWithoutFilters(Model):
    """ChargebackProcessorSettingsWithoutFilters.

    :param billing_period: Billing Period to be processed <span
     class='property-internal'>Required</span>
    :type billing_period: int
    :param start_date_for_bill: Optional Start Date for Bill being generated.
     Only used for Calculate Bill and that too when use is not from sub-meter
     reading
     The bills generated will inherit bill headers (accounting period, invoice
     number, control code, etc ) from the batch <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type start_date_for_bill: datetime
    :param end_date_for_bill: Optional End Date for Bill being generated. Only
     used for Calculate Bill and that too when use is not from sub-meter
     reading
     The bills generated will inherit bill headers (accounting period, invoice
     number, control code, etc ) from the batch <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type end_date_for_bill: datetime
    :param note: Optional note/comment <span class='property-internal'>Must be
     between 0 and 255 characters</span>
    :type note: str
    :param batch_settings: Optional BatchSettings. If provided the batch will
     be created with the settings in here.
     The bills generated will inherit bill headers (accounting period, invoice
     number, control code, etc ) from the batch
    :type batch_settings: ~energycap.sdk.models.BatchCreate
    """

    _validation = {
        'billing_period': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'start_date_for_bill': {'key': 'startDateForBill', 'type': 'iso-8601'},
        'end_date_for_bill': {'key': 'endDateForBill', 'type': 'iso-8601'},
        'note': {'key': 'note', 'type': 'str'},
        'batch_settings': {'key': 'batchSettings', 'type': 'BatchCreate'},
    }

    def __init__(self, billing_period, start_date_for_bill=None, end_date_for_bill=None, note=None, batch_settings=None):
        super(ChargebackProcessorSettingsWithoutFilters, self).__init__()
        self.billing_period = billing_period
        self.start_date_for_bill = start_date_for_bill
        self.end_date_for_bill = end_date_for_bill
        self.note = note
        self.batch_settings = batch_settings
